@@ -1,10 +1,19 @@
+from fastapi import FastAPI
+
 from fastapi_depends.core import FuncType, get_values
 from fastapi_depends.fake_request import FakeRequest
 
 
 class DepContainer:
-    def __init__(self, request: FakeRequest) -> None:
-        self.request = request
+    def __init__(self) -> None:
+        self.key_func_map = {}
+
+    @property
+    def callback_map(self):
+        return self.key_func_map
+
+    def setup_app(self, app: FastAPI):
+        self.request = FakeRequest(app=app)
 
     def inject(self, func: FuncType):
         async def inner(*args, **kwargs):
@@ -31,7 +40,7 @@ class DepContainer:
                 finally:
                     await self.request.scope.get("func_stack").__aexit__(None, None, None)
 
-            setattr(self.request.app, key, inner)
+            self.key_func_map[key] = inner
             return inner
 
         return inject
